@@ -26,9 +26,7 @@
 #include <gtk/gtk.h>
 #include <gio/gdesktopappinfo.h>
 #include <string.h>
-#ifdef VINO_HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
-#endif
 
 #include "vino-status-icon.h"
 #include "vino-enums.h"
@@ -42,9 +40,7 @@ struct _VinoStatusIconPrivate
   GtkWidget  *disconnect_dialog;
   VinoStatusIconVisibility visibility;
 
-#ifdef VINO_HAVE_LIBNOTIFY
   NotifyNotification *new_client_notification;
-#endif
 };
 
 G_DEFINE_TYPE (VinoStatusIcon, vino_status_icon, GTK_TYPE_STATUS_ICON);
@@ -69,11 +65,9 @@ vino_status_icon_finalize (GObject *object)
 {
   VinoStatusIcon *icon = VINO_STATUS_ICON (object);
 
-#ifdef VINO_HAVE_LIBNOTIFY
   if (icon->priv->new_client_notification)
     g_object_unref (icon->priv->new_client_notification);
   icon->priv->new_client_notification = NULL;
-#endif
 
   if (icon->priv->menu)
     gtk_widget_destroy (GTK_WIDGET(icon->priv->menu));
@@ -205,7 +199,9 @@ vino_status_icon_preferences (VinoStatusIcon *icon)
   GError *error = NULL;
 
   screen = gtk_status_icon_get_screen (GTK_STATUS_ICON (icon));
-  info = g_desktop_app_info_new ("vino-preferences.desktop");
+  info = g_desktop_app_info_new ("gnome-sharing-panel.desktop");
+  if (info == NULL)
+    info = g_desktop_app_info_new ("vino-preferences.desktop");
   context = gdk_display_get_app_launch_context (gdk_screen_get_display (screen));
   if (!g_app_info_launch (G_APP_INFO (info), NULL, G_APP_LAUNCH_CONTEXT (context), &error))
     {
@@ -571,19 +567,16 @@ vino_status_icon_class_init (VinoStatusIconClass *klass)
   g_type_class_add_private (gobject_class, sizeof (VinoStatusIconPrivate));
 }
 
-#ifdef VINO_HAVE_LIBNOTIFY
 static void
 vino_status_handle_new_client_notification_closed (VinoStatusIcon *icon)
 {
   g_object_unref (icon->priv->new_client_notification);
   icon->priv->new_client_notification = NULL;
 }
-#endif /* VINO_HAVE_LIBNOTIFY */
 
 static gboolean
 vino_status_icon_show_new_client_notification (gpointer user_data)
 {
-#ifdef VINO_HAVE_LIBNOTIFY
 #define NOTIFICATION_TIMEOUT 5
 
   GError     *error;
@@ -638,25 +631,17 @@ vino_status_icon_show_new_client_notification (gpointer user_data)
     }
 
   icon->priv->new_client_notification =
-#ifdef VINO_HAVE_LIBNOTIFY_0_7
     notify_notification_new (summary,
                              body,
                              "preferences-desktop-remote-desktop");
-#else
-    notify_notification_new_with_status_icon (summary,
-                                              body,
-                                              "preferences-desktop-remote-desktop",
-                                              GTK_STATUS_ICON (icon));
-#endif
 
   g_free (body);
 
   g_signal_connect_swapped (icon->priv->new_client_notification, "closed",
                             G_CALLBACK (vino_status_handle_new_client_notification_closed),
                             icon);
-
   notify_notification_set_hint_string (icon->priv->new_client_notification,
-                                       "desktop-entry", PACKAGE_TARNAME);
+                                       "desktop-entry", "vino-server");
   notify_notification_set_timeout (icon->priv->new_client_notification,
                                    NOTIFICATION_TIMEOUT * 1000);
 
@@ -671,7 +656,6 @@ vino_status_icon_show_new_client_notification (gpointer user_data)
   g_free (user_data);
 
 #undef NOTIFICATION_TIMEOUT
-#endif /* VINO_HAVE_LIBNOTIFY */
 
   return FALSE;
 }
